@@ -2,13 +2,12 @@
 # this repository contains the full copyright notices and license terms.
 
 from trytond.pool import Pool
-from .ir import *
 from .product import *
 
 
 def register():
     Pool.register(
-        Property,
+        ProductCostPrice,
         ProductCostHistory,
         module='product_cost_history', type_='model')
     Pool.register(
