@@ -22,7 +22,7 @@ class ProductCostPrice:
 class ProductCostHistory(ModelSQL, ModelView):
     'History of Product Cost'
     __name__ = 'product.product.cost_history'
-    template = fields.Many2One('product.template', 'Product')
+    product = fields.Many2One('product.product', "Product")
     date = fields.DateTime('Date')
     cost_price = fields.Numeric('Cost Price')
 
@@ -43,11 +43,11 @@ class ProductCostHistory(ModelSQL, ModelView):
             Max(history.write_date).as_('write_date'),
             Coalesce(history.write_date,
                 history.create_date).as_('date'),
-            history.template.as_('template'),
+            history.product.as_('product'),
             history.cost_price.as_('cost_price'),
             group_by=(history.id,
                 Coalesce(history.write_date, history.create_date),
-                history.template, history.cost_price))
+                history.product, history.cost_price))
 
     def get_rec_name(self, name):
         return str(self.date)
@@ -66,11 +66,11 @@ class OpenProductCostHistory(Wizard):
         active_id = Transaction().context.get('active_id')
         if not active_id or active_id < 0:
             action['pyson_domain'] = PYSONEncoder().encode([
-                    ('template', '=', None),
+                    ('product', '=', None),
                     ])
         else:
             product = Product(active_id)
             action['pyson_domain'] = PYSONEncoder().encode([
-                    ('template', '=', product.template.id),
+                    ('product', '=', product.id),
                     ])
         return action, {}
